@@ -11,9 +11,11 @@ fn main() {
     let project = matches.value_of("project").unwrap();
 
     if matches.is_present("hours") {
-        tempus_cli::calc_total_log_time(&project);
+        tempus_cli::print_total_log_time(&project, matches.is_present("today"));
     } else if matches.is_present("start") {
         tempus_cli::print_session_start(&project);
+    } else if matches.is_present("times") {
+        tempus_cli::print_times(&project, matches.is_present("today"));
     } else {
         tempus_cli::do_session(&project);
     }
@@ -21,7 +23,7 @@ fn main() {
 
 fn parse_args() -> ArgMatches<'static> {
     App::new("Tempus")
-        .version("1.0.2")
+        .version("1.1.0")
         .author("Jake Wilson")
         .about("Easy time tracking")
         .arg(Arg::with_name("project")
@@ -38,6 +40,12 @@ fn parse_args() -> ArgMatches<'static> {
             .short("s")
             .long("start")
             .help("Prints current session start time"))
+        .arg(Arg::with_name("today")
+            .long("today")
+            .help("Filters session times to those from today. Use with --hours or --times"))
+        .arg(Arg::with_name("times")
+            .long("times")
+            .help("Prints all session times for a project"))
         .get_matches()
 }
 
